@@ -266,6 +266,10 @@ if not hinted 'osname'; then
 			define osname "bsd"
 			result "BSD"
 			;;
+		*-gnu*)
+			define osname "gnu"
+			result "GNU"
+			;;
 		*)
 			result "no"
 			;;
